@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -57,16 +57,17 @@ public class EasyMock {
      * Creates a mock object that implements the given interface, order checking
      * is disabled by default.
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      *
      * @since 3.4
      */
-    public static <T> T mock(Class<T> toMock) {
-        return createControl().createMock(toMock);
+    public static <T> T mock(Class<?> toMock) {
+        return createControl().mock(toMock);
     }
 
     /**
@@ -77,71 +78,74 @@ public class EasyMock {
      *            the name of the mock object.
      * @param toMock
      *            the class or interface that should be mocked.
-     *
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      *
      * @since 3.4
      */
-    public static <T> T mock(String name, Class<T> toMock) {
-        return createControl().createMock(name, toMock);
+    public static <T> T mock(String name, Class<?> toMock) {
+        return createControl().mock(name, toMock);
     }
 
     /**
      * Creates a mock object, of the requested type, that implements the given interface
      * or extends the given class
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param type
      *            the type of the mock to be created.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object
      *
      * @since 3.4
      */
-    public static <T> T mock(MockType type, Class<T> toMock) {
-        return createControl(type).createMock(toMock);
+    public static <T> T mock(MockType type, Class<?> toMock) {
+        return createControl(type).mock(toMock);
     }
 
     /**
      * Creates a mock object, of the requested type and name, that implements the given interface
      * or extends the given class
      *
-     * @param <T>
-     *            the class or interface that should be mocked.
      * @param name
      *            the name of the mock object.
      * @param type
      *            the type of the mock to be created.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      *
      * @since 3.4
      */
-    public static <T> T mock(String name, MockType type, Class<T> toMock) {
-        return createControl(type).createMock(name, toMock);
+    public static <T> T mock(String name, MockType type, Class<?> toMock) {
+        return createControl(type).mock(name, toMock);
     }
 
     /**
      * Creates a mock object that implements the given interface, order checking
      * is enabled by default.
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      *
      * @since 3.4
      */
-    public static <T> T strictMock(Class<T> toMock) {
-        return createStrictControl().createMock(toMock);
+    public static <T> T strictMock(Class<?> toMock) {
+        return createStrictControl().mock(toMock);
     }
 
     /**
@@ -153,15 +157,16 @@ public class EasyMock {
      * @param toMock
      *            the class or interface that should be mocked.
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      *
      * @since 3.4
      */
-    public static <T> T strictMock(String name, Class<T> toMock) {
-        return createStrictControl().createMock(name, toMock);
+    public static <T> T strictMock(String name, Class<?> toMock) {
+        return createStrictControl().mock(name, toMock);
     }
 
     /**
@@ -169,16 +174,17 @@ public class EasyMock {
      * is disabled by default, and the mock object will return {@code 0},
      * {@code null} or {@code false} for unexpected invocations.
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      *
      * @since 3.4
      */
-    public static <T> T niceMock(Class<T> toMock) {
-        return createNiceControl().createMock(toMock);
+    public static <T> T niceMock(Class<?> toMock) {
+        return createNiceControl().mock(toMock);
     }
 
     /**
@@ -190,33 +196,33 @@ public class EasyMock {
      *            the name of the mock object.
      * @param toMock
      *            the class or interface that should be mocked.
-     *
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      *
      * @since 3.4
      */
-    public static <T> T niceMock(String name, Class<T> toMock) {
-        return createNiceControl().createMock(name, toMock);
+    public static <T> T niceMock(String name, Class<?> toMock) {
+        return createNiceControl().mock(name, toMock);
     }
 
     /**
      * Create a mock builder allowing to create a partial mock for the given
      * class or interface.
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement.
      * @return a mock builder to create a partial mock
      *
      * @since 3.4
      */
-    public static <T> IMockBuilder<T> partialMockBuilder(Class<T> toMock) {
-        return new MockBuilder<T>(toMock);
+    public static <T> IMockBuilder<T> partialMockBuilder(Class<?> toMock) {
+        return new MockBuilder<>(toMock);
     }
 
     /**
@@ -225,16 +231,17 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #mock(MockType, Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param type
      *            the type of the mock to be created.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @since 3.2
      */
-    public static <T> T createMock(MockType type, Class<T> toMock) {
+    public static <T> T createMock(MockType type, Class<?> toMock) {
         return mock(type, toMock);
     }
 
@@ -244,18 +251,19 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #mock(String, MockType, Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the class or interface that should be mocked.
      * @param name
      *            the name of the mock object.
      * @param type
      *            the type of the mock to be created.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @since 3.2
      */
-    public static <T> T createMock(String name, MockType type, Class<T> toMock) {
+    public static <T> T createMock(String name, MockType type, Class<?> toMock) {
         return mock(name, type, toMock);
     }
 
@@ -265,13 +273,14 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #strictMock(Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      */
-    public static <T> T createStrictMock(Class<T> toMock) {
+    public static <T> T createStrictMock(Class<?> toMock) {
         return strictMock(toMock);
     }
 
@@ -286,12 +295,13 @@ public class EasyMock {
      * @param toMock
      *            the class or interface that should be mocked.
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      */
-    public static <T> T createStrictMock(String name, Class<T> toMock) {
+    public static <T> T createStrictMock(String name, Class<?> toMock) {
         return strictMock(name, toMock);
     }
 
@@ -301,13 +311,14 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #mock(Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      */
-    public static <T> T createMock(Class<T> toMock) {
+    public static <T> T createMock(Class<?> toMock) {
         return mock(toMock);
     }
 
@@ -321,14 +332,14 @@ public class EasyMock {
      *            the name of the mock object.
      * @param toMock
      *            the class or interface that should be mocked.
-     *
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      */
-    public static <T> T createMock(String name, Class<T> toMock) {
+    public static <T> T createMock(String name, Class<?> toMock) {
         return mock(name, toMock);
     }
 
@@ -339,13 +350,14 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #niceMock(Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      */
-    public static <T> T createNiceMock(Class<T> toMock) {
+    public static <T> T createNiceMock(Class<?> toMock) {
         return niceMock(toMock);
     }
 
@@ -360,14 +372,14 @@ public class EasyMock {
      *            the name of the mock object.
      * @param toMock
      *            the class or interface that should be mocked.
-     *
      * @param <T>
-     *            the interface that the mock object should implement.
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return the mock object.
      * @throws IllegalArgumentException
      *             if the name is not a valid Java identifier.
      */
-    public static <T> T createNiceMock(String name, Class<T> toMock) {
+    public static <T> T createNiceMock(String name, Class<?> toMock) {
         return niceMock(name, toMock);
     }
 
@@ -377,13 +389,14 @@ public class EasyMock {
      * <p>
      * <b>Note:</b> This is the old version of {@link #partialMockBuilder(Class)}, which is more completion friendly
      *
-     * @param <T>
-     *            the interface that the mock object should implement.
      * @param toMock
      *            the class or interface that should be mocked.
+     * @param <T>
+     *            the interface that the mock object should implement. It is expected to be of
+     *            class {@code toMock}.
      * @return a mock builder to create a partial mock
      */
-    public static <T> IMockBuilder<T> createMockBuilder(Class<T> toMock) {
+    public static <T> IMockBuilder<T> createMockBuilder(Class<?> toMock) {
         return partialMockBuilder(toMock);
     }
 
@@ -610,7 +623,7 @@ public class EasyMock {
      * @return {@code null}.
      */
     public static <T extends Comparable<T>> T geq(T value) {
-        reportMatcher(new GreaterOrEqual<T>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return value;
     }
 
@@ -623,7 +636,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static byte geq(byte value) {
-        reportMatcher(new GreaterOrEqual<Byte>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -636,7 +649,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static double geq(double value) {
-        reportMatcher(new GreaterOrEqual<Double>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -649,7 +662,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static float geq(float value) {
-        reportMatcher(new GreaterOrEqual<Float>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -662,7 +675,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static int geq(int value) {
-        reportMatcher(new GreaterOrEqual<Integer>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -675,7 +688,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static long geq(long value) {
-        reportMatcher(new GreaterOrEqual<Long>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -688,7 +701,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static short geq(short value) {
-        reportMatcher(new GreaterOrEqual<Short>(value));
+        reportMatcher(new GreaterOrEqual<>(value));
         return 0;
     }
 
@@ -703,7 +716,7 @@ public class EasyMock {
      * @return {@code null}.
      */
     public static <T extends Comparable<T>> T leq(T value) {
-        reportMatcher(new LessOrEqual<T>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return value;
     }
 
@@ -716,7 +729,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static byte leq(byte value) {
-        reportMatcher(new LessOrEqual<Byte>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -729,7 +742,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static double leq(double value) {
-        reportMatcher(new LessOrEqual<Double>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -742,7 +755,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static float leq(float value) {
-        reportMatcher(new LessOrEqual<Float>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -755,7 +768,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static int leq(int value) {
-        reportMatcher(new LessOrEqual<Integer>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -768,7 +781,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static long leq(long value) {
-        reportMatcher(new LessOrEqual<Long>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -781,7 +794,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static short leq(short value) {
-        reportMatcher(new LessOrEqual<Short>(value));
+        reportMatcher(new LessOrEqual<>(value));
         return 0;
     }
 
@@ -796,7 +809,7 @@ public class EasyMock {
      * @return {@code null}.
      */
     public static <T extends Comparable<T>> T gt(T value) {
-        reportMatcher(new GreaterThan<T>(value));
+        reportMatcher(new GreaterThan<>(value));
         return value;
     }
 
@@ -809,7 +822,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static byte gt(byte value) {
-        reportMatcher(new GreaterThan<Byte>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -822,7 +835,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static double gt(double value) {
-        reportMatcher(new GreaterThan<Double>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -835,7 +848,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static float gt(float value) {
-        reportMatcher(new GreaterThan<Float>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -848,7 +861,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static int gt(int value) {
-        reportMatcher(new GreaterThan<Integer>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -861,7 +874,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static long gt(long value) {
-        reportMatcher(new GreaterThan<Long>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -874,7 +887,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static short gt(short value) {
-        reportMatcher(new GreaterThan<Short>(value));
+        reportMatcher(new GreaterThan<>(value));
         return 0;
     }
 
@@ -889,7 +902,7 @@ public class EasyMock {
      * @return {@code null}.
      */
     public static <T extends Comparable<T>> T lt(T value) {
-        reportMatcher(new LessThan<T>(value));
+        reportMatcher(new LessThan<>(value));
         return value;
     }
 
@@ -902,7 +915,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static byte lt(byte value) {
-        reportMatcher(new LessThan<Byte>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -915,7 +928,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static double lt(double value) {
-        reportMatcher(new LessThan<Double>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -928,7 +941,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static float lt(float value) {
-        reportMatcher(new LessThan<Float>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -941,7 +954,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static int lt(int value) {
-        reportMatcher(new LessThan<Integer>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -954,7 +967,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static long lt(long value) {
-        reportMatcher(new LessThan<Long>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -967,7 +980,7 @@ public class EasyMock {
      * @return {@code 0}.
      */
     public static short lt(short value) {
-        reportMatcher(new LessThan<Short>(value));
+        reportMatcher(new LessThan<>(value));
         return 0;
     }
 
@@ -1780,7 +1793,7 @@ public class EasyMock {
      * @return {@code null}.
      */
     public static <T extends Comparable<T>> T cmpEq(T value) {
-        reportMatcher(new CompareEqual<T>(value));
+        reportMatcher(new CompareEqual<>(value));
         return value;
     }
 
@@ -1803,7 +1816,7 @@ public class EasyMock {
      * @return {@code null}
      */
     public static <T> T cmp(T value, Comparator<? super T> comparator, LogicalOperator operator) {
-        reportMatcher(new Compare<T>(value, comparator, operator));
+        reportMatcher(new Compare<>(value, comparator, operator));
         return value;
     }
 
@@ -1838,7 +1851,7 @@ public class EasyMock {
      * @return {@code null}
      */
     public static <T> T capture(Capture<T> captured) {
-        reportMatcher(new Captures<T>(captured));
+        reportMatcher(new Captures<>(captured));
         return null;
     }
 
@@ -1850,7 +1863,7 @@ public class EasyMock {
      * @return {@code false}
      */
     public static boolean captureBoolean(Capture<Boolean> captured) {
-        reportMatcher(new Captures<Boolean>(captured));
+        reportMatcher(new Captures<>(captured));
         return false;
     }
 
@@ -1862,7 +1875,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static int captureInt(Capture<Integer> captured) {
-        reportMatcher(new Captures<Integer>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
@@ -1874,7 +1887,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static long captureLong(Capture<Long> captured) {
-        reportMatcher(new Captures<Long>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
@@ -1886,7 +1899,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static float captureFloat(Capture<Float> captured) {
-        reportMatcher(new Captures<Float>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
@@ -1898,7 +1911,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static double captureDouble(Capture<Double> captured) {
-        reportMatcher(new Captures<Double>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
@@ -1910,7 +1923,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static byte captureByte(Capture<Byte> captured) {
-        reportMatcher(new Captures<Byte>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
@@ -1922,7 +1935,7 @@ public class EasyMock {
      * @return {@code 0}
      */
     public static char captureChar(Capture<Character> captured) {
-        reportMatcher(new Captures<Character>(captured));
+        reportMatcher(new Captures<>(captured));
         return 0;
     }
 
