@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -52,9 +52,9 @@ public enum LogicalOperator {
         }
     };
 
-    private String symbol;
+    private final String symbol;
 
-    private LogicalOperator(String symbol) {
+    LogicalOperator(String symbol) {
         this.symbol = symbol;
     }
 
