@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,7 +22,7 @@ import org.objenesis.ObjenesisHelper;
  */
 public class ObjenesisClassInstantiator implements IClassInstantiator {
 
-    public Object newInstance(Class<?> clazz) throws InstantiationException {
+    public Object newInstance(Class<?> clazz) {
         return ObjenesisHelper.newInstance(clazz);
     }
 
