@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -33,10 +33,10 @@ public class Contains implements IArgumentMatcher, Serializable {
     }
 
     public boolean matches(Object actual) {
-        return (actual instanceof String) && ((String) actual).indexOf(substring) >= 0;
+        return (actual instanceof String) && ((String) actual).contains(substring);
     }
 
     public void appendTo(StringBuffer buffer) {
-        buffer.append("contains(\"" + substring + "\")");
+        buffer.append("contains(\"").append(substring).append("\")");
     }
 }
