@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,6 +37,6 @@ public class InstanceOf implements IArgumentMatcher, Serializable {
     }
 
     public void appendTo(StringBuffer buffer) {
-        buffer.append("isA(" + clazz.getName() + ")");
+        buffer.append("isA(").append(clazz.getName()).append(")");
     }
 }
