@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,6 +38,6 @@ public class Matches implements IArgumentMatcher, Serializable {
     }
 
     public void appendTo(StringBuffer buffer) {
-        buffer.append("matches(\"" + regex.pattern().replaceAll("\\\\", "\\\\\\\\") + "\")");
+        buffer.append("matches(\"").append(regex.pattern().replaceAll("\\\\", "\\\\\\\\")).append("\")");
     }
 }
