@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,6 +37,6 @@ public class StartsWith implements IArgumentMatcher, Serializable {
     }
 
     public void appendTo(StringBuffer buffer) {
-        buffer.append("startsWith(\"" + prefix + "\")");
+        buffer.append("startsWith(\"").append(prefix).append("\")");
     }
 }
