@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,7 +45,7 @@ public class ArgumentToStringTest {
 
     @Test
     public void testAppendArgument_Character() {
-        assertString("'c'", Character.valueOf('c'));
+        assertString("'c'", 'c');
     }
 
     @Test
