@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -33,7 +33,7 @@ public class CapturesMatcherTest {
 
     private final Capture<String> capture = Capture.newInstance(CaptureType.ALL);
 
-    private final Captures<String> matcher = new Captures<String>(capture);
+    private final Captures<String> matcher = new Captures<>(capture);
 
     private StringBuffer buffer;
 
@@ -49,7 +49,7 @@ public class CapturesMatcherTest {
     }
 
     @Test
-    public void test() throws Exception {
+    public void test() {
 
         matcher.appendTo(buffer);
         assertEquals("capture(Nothing captured yet)", buffer.toString());
