@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -32,7 +32,7 @@ import static org.junit.Assert.*;
 public class GenericTest {
 
     public interface C<U> {
-        public void doCMethod(U u);
+        void doCMethod(U u);
     }
 
     public class B implements C<Integer> {
@@ -44,9 +44,9 @@ public class GenericTest {
     @Test
     public void testTheBridgeMethodIsRecordedNotTheBridge() {
         B b = createMock(B.class);
-        b.doCMethod(Integer.valueOf(6));
+        b.doCMethod(6);
         replay(b);
-        b.doCMethod(Integer.valueOf(6));
+        b.doCMethod(6);
         verify(b);
     }
 
@@ -117,7 +117,6 @@ public class GenericTest {
     @Test
     public void testBridgedEquals() {
         ChildEquals c = createMock(ChildEquals.class);
-        assertTrue(c.equals(c));
-
+        assertEquals(c, c);
     }
 }
