@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -47,7 +47,7 @@ public class UsageStrictMockTest {
     }
 
     @Test
-    public void orderedCallsSucces() {
+    public void orderedCallsSuccess() {
         mock.simpleMethodWithArgument("1");
         mock.simpleMethodWithArgument("2");
 
@@ -91,8 +91,8 @@ public class UsageStrictMockTest {
             verify(mock);
         } catch (AssertionError expected) {
             failed = true;
-            assertTrue("stack trace must be filled in", Util.getStackTrace(expected).indexOf(
-                    ReplayState.class.getName()) == -1);
+            assertEquals("stack trace must be filled in", Util.getStackTrace(expected).indexOf(
+                ReplayState.class.getName()), -1);
         }
         if (!failed) {
             fail("too few calls accepted");
@@ -111,7 +111,7 @@ public class UsageStrictMockTest {
         expectLastCall().atLeastOnce();
 
         replay(mock);
-        assertEquals(true, mock.booleanReturningMethod(0));
+        assertTrue(mock.booleanReturningMethod(0));
         mock.simpleMethod();
 
         boolean failed = false;
@@ -128,7 +128,7 @@ public class UsageStrictMockTest {
             fail("too few calls accepted");
         }
 
-        assertEquals(false, mock.booleanReturningMethod(1));
+        assertFalse(mock.booleanReturningMethod(1));
 
         failed = false;
         try {
@@ -189,11 +189,11 @@ public class UsageStrictMockTest {
 
         replay(mock);
 
-        assertEquals(true, mock.booleanReturningMethod(2));
-        assertEquals(true, mock.booleanReturningMethod(3));
-        assertEquals(true, mock.booleanReturningMethod(1));
-        assertEquals(false, mock.booleanReturningMethod(1));
-        assertEquals(true, mock.booleanReturningMethod(3));
+        assertTrue(mock.booleanReturningMethod(2));
+        assertTrue(mock.booleanReturningMethod(3));
+        assertTrue(mock.booleanReturningMethod(1));
+        assertFalse(mock.booleanReturningMethod(1));
+        assertTrue(mock.booleanReturningMethod(3));
 
         boolean failed = false;
         try {
