@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright 2001-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,11 +15,16 @@
  */
 package org.easymock.tests;
 
+import org.easymock.IMocksControl;
+import org.easymock.MockType;
+import org.easymock.internal.MocksControl;
+import org.easymock.internal.ObjectMethodsFilter;
+
 import java.io.PrintWriter;
 import java.io.StringWriter;
 
 /**
- * @author OFFIS, Tammo Freese
+ * @author OFFIS, Tammo Freese, Henri Tremblay
  */
 public final class Util {
 
@@ -36,4 +41,18 @@ public final class Util {
         StackTraceElement[] elements = throwable.getStackTrace();
         return elements[0].getClassName().equals(clazz.getName());
     }
+
+    public static IMocksControl getControl(Object o) {
+        return MocksControl.getControl(o);
+    }
+
+    public static MockType getType(Object o) {
+        IMocksControl control = MocksControl.getControl(o);
+        return ((MocksControl) control).getType();
+    }
+
+    public static String getName(Object o) {
+        ObjectMethodsFilter handler = (ObjectMethodsFilter) MocksControl.getInvocationHandler(o);
+        return handler.getName();
+    }
 }
